close all
clear all
clc

% Ovo je m-datoteka s primjerima s prvog predavanja

% znak "%" oznacava da tekst koji slijedi u toj liniji je komentar 
% (matlab ga ignorira)


%% POMOC
help

help elfun     % pomoc o elementarnim funkcijama

help ops       % pomoc o operatorima

help format    % pomoc o formatima ispisa numerickih rezultata

help lang      % pomoc o naredbama za upravljanje tokom programa

help general   % pomoc o opcim naredbama

help elmat     % elementarne matrice i manipulacija matricama

intro

demo



%% MATLAB KAO KALKULATOR

rezultat1 = 15^2/(3^6-6^3)    % ^ je potenciranje, / je dijeljenje

help ^
help /

% koristenjem ; na kraju retka postizemo da se rezultat tog retka ne
% ispisuje na ekranu, iako se redak izvrsio :

rezultat2 = 2*log(exp(1)) + cos(pi);     % * je mnozenje
rezultat2

% ulazni argumenti trigonometrijskih funkcija su u rad
sin(90) % sinus od 90 radijana = 0.8940
sin(90*pi/180) % sinus od 90 stupnjeva = 1
sind(90) % ulazni argument je sada u stupnjevima

help log
help exp
help pi



%% TIPOVI PODATAKA

% BROJEVI - double

% Double-Precision Floating Point
% MATLAB constructs the double-precision (or double) data type according to IEEE Standard 754 
% for double precision. Any value stored as a double requires 64 bits, formatted as shown below:
% Bits: 63, Usage: Sign (0 = positive, 1 = negative)
% Bits: 62 to 52, Usage: Exponent, biased by 1023  
% Bits: 51 to 0, Usage: Fraction f of the number 1.f	

help double

help single

help int16

int16(pi)

help datatypes



% MATLABove KONSTANTE I VARIJABLE

pi   % = 3.14156965...

% "i" i "j" kao kompleksne jedinice
i^2
j^2     
sqrt(-1)

% tocnost; najmanja udaljenost od 1 do sljedeceg broja
eps    

1 == 1 + eps    % daje izlaz 0, to znaci FALSE (nije istina da je 1 jednako 1+eps)
1 == 1 + eps/2  % daje izlaz 1, to znaci TRUE (za Matlab, 1 je jednako 1+eps/2)

inf            % beskonacno
1/0            % = inf
inf - 10000    % = inf
1/inf          % = 0

NaN   % "Not a number"
0/0   % = NaN 
help NaN

realmax   % najveci realni broj
realmin   % najmanji realni broj


% ZNAKOVI I NIZOVI ZNAKOVA ("stringovi")

help strings

S1 = 'Dobar dan, ';
S2 = 'gospodine ';

S = strcat(S1, S2)



%% VEKTORI I MATRICE 

% kod zadavanja matrica koriste se uglate zagrade!

% vektor redak:
v = [1 2 3]    % ili v=[1,2,3];

% vektor stupac
v1 = [1; 2; 3]

% realna matrica s dva retka i tri stupca   
% tocka-zarez ; oznacava mjesto prijelaza u sljedeci redak
% prilikom upisa martice, za prijelaz s i-tog u (i+1) elementa u redku 
% koristi se ili prazno mjesto ili zarez 
B = [1 2 3; 4 5 6] 
B = [6, 5, 4; 3, 2, 1]

% Elementarne matematicke ugradene funkcije su vektorizirane
sin(v)
exp(B)

% kompleksan vektor   
v2 = [2;4;1] + i*[1;2;3]   

% ovdje je i imaginarna jedinica (i^2=-1)
i^2
sqrt(-1)

% kompleksna matrica dimenzija 2 x 2
A = [i, 1+0.5*i; -2-i, 4-5*i]           
real(A)     % realan dio matrice A
imag(A)     % imaginaran dio matrice A

% koristenjem ; na kraju retka postizemo da se rezultat tog retka ne
% ispisuje na ekranu, iako se redak izvrsio
C = real(A) + [1, 1; 2, 2];
C


% Kreiranje vektorra ciji su elementi nizovi brojeva

% vektor brojeva od 1 do 10 s korakom 0.2:
niz1 = 1:0.2:10

% vektor brojeva od 5 do -3 s korakom -0.5:
niz2 = 5:-0.5:-3

% ako se korak ne navede, uzima se da je jedank jedinici
niz3 = -3:3

niz4 = 3:-3    % ne radi, tj. kreira praznu matricu (vektor)
niz4 = 3:-1:-3 % radi

niz5 = linspace(1, 5, 10) % 10 brojeva izmedju 1 i 5 lin. rasporedenih
niz6 = logspace(1, 3, 10) % 10 brojeva izmedju 10^1 i 10^3 log. rasporedenih

% dodavanje elementa na kraj vec postojeceg vektora
v = [1, 2, 3];
v(end) % zadnji element vektora v
v(end+1) = 5;
v

% Kreiranje matrice sa slucajnnim elementima
help rand
B = rand(3)
C = rand(3, 6)


% KREIRANJE "POSEBNIH" VRSTA MATRICA :

% nul matrica dimanzija 2 x 5
M1 = zeros(2, 5)          

% matrica dimenzija 2 x 3 kojoj su svi elementi jednaki 1
M2 = ones(2, 3)           

% dijagonalna matrica
M3 = diag([1; 2; 3])     

% jedinicna matrica dimenzija 5 x 5
M4  = eye(5)              

% blok dijagonalna matrica
M5 = blkdiag(M2, M3, M4) 


% Kreiranje matrice unosom podmatrica:
A = diag([1;2;3])
B = rand(3, 2);

C = [A, B; zeros(2,size(A,2)), ones(2,size(B,2))]


% INDEKSIRANJE, ODABIRANJE ELEMENATA MATRICE

v = 1:5     % kreira vektor-redak v = [1 2 3 4 5]

v1 = v'     % vektor-redak -->vektor-stupac (' oznacava transponiranje) 

v(3)     % treci element vektora v
v1(4)    % cetvrti element vektora v    

% dakle, kad se radi o vektoru, indeksiramo njegov element jednako i za vektor stupac i za vektor redak

             
M = [1 2 3; 4 5 6; 7 8 9]             

[broj_redaka, broj_stupaca] = size(M)

% element matrice M iz drugog retka i treceg stupca
M(2, 3) 

% sesti element iz vektora koji se dobije kad se M "razvije" po stupcima
M(6)

% vektor stupac koji sadrzi sve elemenata matrice M "razvijene po stupcima"
% tzv. vektorizacija matrice
M(:)       

% svi elementi drugog redka 
M(2, :)

% svi elementi prvog stupca
M(:, 1)   

% podmatrica matrice M - elementi iz 2. i 3. retka, 1. i 2. stupca
M(2:3, 1:2)   

% podmatrica matrice M - elementi iz 1. i 3. retka, 1. i 3. stupca
M([1 3], [1 3])  

% matrica M1 dobivena je iz M zamjenom 1. i 3. retka
M1 = M([3 2 1], :)  

% brisanje drugog stupca matrice M1
M1
M1(:, 2) = [];
M1

% brisanje zadnjeg retka matrice M
M
M(end, :) = [];    
M

% dodavanje vektora stupca nakon trenutno zadnjeg stupca u matrici
M(:, end+1) = [100;101];  
M



%% POLINOMI


% Polinom se predstavlja vektorom koji sadrzi njegove koeficijente.
% Polinom n-tog stupnja ima n+1 koeficijent

% primjer: zadan je polinom P(x)=2*x^3-3*x^2+2
% Vektor koeficijenata koji definira ovaj polinom:
P = [2 -3 0 2];

% kojem polinomu odgovara sljedeci vektor?
P1 = [3 0 0 0 1 1];

% odgovor: P1(x)=3*x^5+x+1

% ovakav zapis polinoma konvnecija je za naradbe koje rade s polinomima
% primjer:
% polyval(f, x)  racuna vrijednost polinoma f u tocki x
polyval(P1, 0)

% ako je x vektor, polyval(f, x) daje vektor [f(x1), f(x2),...] 
x = -3:0.1:3;
y = polyval(P1, x);
plot(x, y)